\begin{lstlisting}
function wave=etasolutioncomplex(r,theta,k,a,tol)
%This function evaluates the analytical solution in polar coordinates given as 'r' and 'theta' to a given tolerance, 'tol', and returns the complex result. The wavenumber and the radius of the structure is given by 'k' and 'a', respectively. The function has been highly optimized, by tabulating the besselfunctions, and bypassing standard Matlab checks.
if nargin<5
tol=1e-7;
end
A=1;
%Initialize.
A=A(1);
a=a(1);
k=k(1);
tol=tol(1);
ka=k*a;
count=1;
eta=0;
%wave=zeros(1,length(r)*length(theta));
jdiff0=(-ka.*besselmx(real('J'),1,ka,0))./ka;
hdiff0=(-ka.*besselmx(real('H'),1,ka,0))./ka;
pmax=0;
%Loop over r then theta.
for g=1:length(r)
    if abs(r(g))>=1
        kr=k.*r(g);
        bjkr0=besselmx(real('J'),0,kr,0);
        bhkr0=besselmx(real('H'),0,kr,0);
        qmax=0;
        for d=1:length(theta)
            % Calculation of wave field in polar coordinates.
            %Calculate first step (where E=1).
            j=0;
            E=1;
	    eta=A.*E.*i.^j.*(bjkr0-bhkr0.*(jdiff0./hdiff0)).*cos(j.*theta(d));
            lastterm(count)=eta;
            E=2;
            gamma=1;
	    delta=1;
            %Calculate rest of the sum.
            while gamma>tol & delta>tol
                j=j+1;
                if j>pmax
                    jdiff(j,:)=(-ka.*besselmx(real('J'),j+1,ka,0)+j.*besselmx(real('J'),j,ka,0))./ka;
                    hdiff(j,:)=(-ka.*besselmx(real('H'),j+1,ka,0)+j.*besselmx(real('H'),j,ka,0))./ka;
                    pmax=pmax+1;
                end
                if j>qmax
                    bjkr(j,:)=besselmx(real('J'),j,kr,0);
                    bhkr(j,:)=besselmx(real('H'),j,kr,0);
                    qmax=qmax+1;
                end
		count=count+1;
                lastterm(count)=A.*E.*i.^j.*(bjkr(j)-bhkr(j).*(jdiff(j)./hdiff(j))).*cos(j*theta(d));
                eta=eta+lastterm(count);
                gamma=abs(lastterm(count))./abs(eta);
		delta=abs(lastterm(count-1))./abs(eta);	
            end
            wave(g,d)=eta;
        end
    else
        wave(g,1:length(theta))=3;
    end
    g
end
\end{lstlisting}
